package com.yunfeiyun.agmp.fms.service.impl;

import java.util.List;

import com.yunfeiyun.agmp.fms.domain.WmsChangeapplyitem;
import com.yunfeiyun.agmp.fms.mapper.WmsChangeapplyitemMapper;
import com.yunfeiyun.agmp.fms.service.IWmsChangeapplyitemService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 变动申请物件Service业务层处理
 * 
 * @author 杨晓辉
 * @date 2023-05-25
 */
@Service
public class WmsChangeapplyitemServiceImpl implements IWmsChangeapplyitemService
{
    @Autowired
    private WmsChangeapplyitemMapper wmsChangeapplyitemMapper;

    /**
     * 查询变动申请物件
     * 
     * @param changeapplyitemId 变动申请物件主键
     * @return 变动申请物件
     */
    @Override
    public WmsChangeapplyitem selectWmsChangeapplyitemByChangeapplyitemId(String changeapplyitemId)
    {
        return wmsChangeapplyitemMapper.selectWmsChangeapplyitemByChangeapplyitemId(changeapplyitemId);
    }

    /**
     * 查询变动申请物件列表
     * 
     * @param wmsChangeapplyitem 变动申请物件
     * @return 变动申请物件
     */
    @Override
    public List<WmsChangeapplyitem> selectWmsChangeapplyitemList(WmsChangeapplyitem wmsChangeapplyitem)
    {
        return wmsChangeapplyitemMapper.selectWmsChangeapplyitemList(wmsChangeapplyitem);
    }

    /**
     * 新增变动申请物件
     * 
     * @param wmsChangeapplyitem 变动申请物件
     * @return 结果
     */
    @Override
    public int insertWmsChangeapplyitem(WmsChangeapplyitem wmsChangeapplyitem)
    {
        return wmsChangeapplyitemMapper.insertWmsChangeapplyitem(wmsChangeapplyitem);
    }

    /**
     * 修改变动申请物件
     * 
     * @param wmsChangeapplyitem 变动申请物件
     * @return 结果
     */
    @Override
    public int updateWmsChangeapplyitem(WmsChangeapplyitem wmsChangeapplyitem)
    {
        return wmsChangeapplyitemMapper.updateWmsChangeapplyitem(wmsChangeapplyitem);
    }

    /**
     * 批量删除变动申请物件
     * 
     * @param changeapplyitemIds 需要删除的变动申请物件主键
     * @return 结果
     */
    @Override
    public int deleteWmsChangeapplyitemByChangeapplyitemIds(String[] changeapplyitemIds)
    {
        return wmsChangeapplyitemMapper.deleteWmsChangeapplyitemByChangeapplyitemIds(changeapplyitemIds);
    }

    /**
     * 删除变动申请物件信息
     * 
     * @param changeapplyitemId 变动申请物件主键
     * @return 结果
     */
    @Override
    public int deleteWmsChangeapplyitemByChangeapplyitemId(String changeapplyitemId)
    {
        return wmsChangeapplyitemMapper.deleteWmsChangeapplyitemByChangeapplyitemId(changeapplyitemId);
    }
}
